@@ -3,7 +3,7 @@
     Author:        Jan Wielemaker
     E-mail:        J.Wielemaker@vu.nl
     WWW:           http://www.swi-prolog.org
-    Copyright (c)  1997-2021, University of Amsterdam
+    Copyright (c)  1997-2022, University of Amsterdam
                               VU University Amsterdam
 			      CWI, Amsterdam
 			      SWI-Prolog Solutions b.v.
@@ -122,6 +122,7 @@ struct PL_global_data
   { int		os_argc;		/* main(int argc, char **argv) */
     char **	os_argv;
     int		appl_argc;		/* Application options */
+    int		appl_malloc;		/* Array is allocated */
     char **	appl_argv;
     int		notty;			/* -tty: do not use ioctl() */
     int		optimise;		/* -O: optimised compilation */
@@ -324,7 +325,8 @@ struct PL_global_data
     Procedure	prolog_break_hook6;	/* prolog:break_hook/6 */
     Procedure	portray;		/* portray/1 */
     Procedure   dcall1;			/* $call/1 */
-    Procedure   call3;			/* call/3*/
+    Procedure   call1;			/* call/1 */
+    Procedure   call3;			/* call/3 */
     Procedure	setup_call_catcher_cleanup4; /* setup_call_catcher_cleanup/4 */
     Procedure	undefinterc4;		/* $undefined_procedure/4 */
     Procedure   dthread_init0;		/* $thread_init/0 */
@@ -338,6 +340,24 @@ struct PL_global_data
     Procedure	tune_gc3;		/* prolog:tune_gc */
     Procedure	trie_gen_compiled2;
     Procedure	trie_gen_compiled3;
+    Procedure	exception3;		/* user:exception/3 */
+    Procedure	iri_hook4;		/* $iri:iri_hook/4 */
+    Procedure	absolute_file_name3;	/* system:absolute_file_name/3 */
+    Procedure	c_open_resource3;	/* $rc:c_open_resource/3 */
+    Procedure	clear_source_admin1;	/* system:$clear_source_admin/1 */
+    Procedure	answer_completion2;	/* $tabling:answer_completion/2 */
+    Procedure	update7;		/* $tabling:update/7 */
+    Procedure	answer_count_restraint0;/* $tabling:answer_count_restraint/0 */
+    Procedure	radial_restraint0;	/* $tabling:radial_restraint/0 */
+    Procedure	tripwire3;		/* $tabling:tripwire/3 */
+#if O_PLMT
+    Procedure	signal_is_blocked1;	/* $syspreds:signal_is_blocked1/1 */
+    Procedure	dgc0;			/* system:$gc/0 */
+#endif
+    Procedure	drun_undo1;		/* $syspreds:$run_undo/1 */
+    Procedure	drun_initialization2;	/* system:$run_initialization/2 */
+    Procedure	dtranslated_source2;	/* system:$translated_source/2 */
+    Procedure	findall_loop4;		/* $bags:findall_loop/4 */
 
     int		static_dirty;		/* #static dirty procedures */
 #ifdef O_CLAUSEGC
@@ -345,6 +365,11 @@ struct PL_global_data
 #endif
   } procedures;
 
+  struct				/* see raiseInferenceLimitException() */
+  { int		initialized;
+    predicate_t	not_exceed_[6];
+  } inference_limit;
+
   struct
   { ClauseRef	lingering;		/* Unlinked clause refs */
     size_t	lingering_count;	/* # Unlinked clause refs */
@@ -403,9 +428,14 @@ struct PL_global_data
     { pthread_mutex_t	mutex;
       pthread_cond_t	cond;
     } index;
+    linger_list	       *lingering;
   } thread;
 #endif /*O_PLMT*/
 
+  struct
+  { functor_t dict_functors[CACHED_DICT_FUNCTORS];
+  } dict;
+
 #ifdef O_LOCALE
   struct
   { Table		localeTable;	/* Name --> locale table */
@@ -413,6 +443,10 @@ struct PL_global_data
   } locale;
 #endif
 
+  struct
+  { int tz_initialized;			/* time zone is initialized */
+  } date;
+
   struct stack		combined_stack; /* ID for combined stack */
 };
 
@@ -758,6 +792,13 @@ struct PL_local_data
     int64_t	cgc_inferences;		/* Inferences at last cgc consider */
   } clauses;
 
+#ifdef O_COVERAGE
+  struct
+  { Table	table;			/* Table for recording data */
+    int		active;			/* We are recording */
+  } coverage;
+#endif
+
   struct
   { gen_t	generation;		/* reload generation */
     int		nesting;		/* reload nesting */
