@@ -63,6 +63,7 @@
 #include "pl-proc.h"
 #include "pl-pro.h"
 #include "pl-gvar.h"
+#include "pl-coverage.h"
 #include <sys/stat.h>
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
@@ -672,6 +673,8 @@ prepareSignal(int sig, int plsig_flags)
       if ( current_state == 0 )
         sh->saved_handler = old_handler;
     }
+  } else
+  { sh->flags = (sh->flags & ~PLSIG_USERFLAGS) | plsig_flags;
   }
 
   return sh;
@@ -1781,6 +1784,10 @@ freePrologLocalData(PL_local_data_t *ld)
     free(ld->signal.alt_stack);
 #endif
 
+#ifdef O_COVERAGE
+  free_coverage_data(ld);
+#endif
+
   free_undo_data(ld);
 
   if ( ld->btrace_store )
